getNameOfCurrentTarget_fix {#master}
-------------------------

## Important Changes

### Devices

#### fakeNavigation
* improved `fakeNavigationDev` for testing purposes

#### Navigation2DClient
* fixed `getNameOfCurrentTarget()` method moving logic from `Navigation2DClient` to `navigation2DServer`

### Test

#### Harness_dev
* added new tests to `Navigation2DClientTest.cpp`